<!-- The (first) h1 will be used as the <title> of the HTML page -->
# Richard Hendricks

<!-- The unordered list immediately after the h1 will be formatted on a single
line. It is intended to be used for contact details -->
- <richard.hendriks@mail.com>
- (912) 555-4321
- [richardhendricks.example.com](http://richardhendricks.example.com)
- San Francisco, CA

<!-- The paragraph after the h1 and ul and before the first h2 is optional. It
is intended to be used for a short summary. -->
CEO and Software Engineer with knowledge of applied information theory,
including optimizing lossless compression schema of both the length-limited and
adaptive variants.

## Experience

<!-- You have to wrap the "left" and "right" half of these headings in spans by
hand -->
### <span>CEO/President, Pied Piper</span> <span>Dec 2013 -- Dec 2014</span>

Pied Piper is a multi-platform technology based on a proprietary universal
compression algorithm that has consistently fielded high Weisman Scores™ that
are not merely competitive, but approach the theoretical limit of lossless
compression.

 - Build an algorithm for artist to detect if their music was violating
   copyright infringement laws
 - Successfully won Techcrunch Disrupt
 - Optimized an algorithm that holds the current world record for Weisman Scores

### <span>Teacher, CoderDojo</span> <span>July 2013 -- Dec 2013</span>

Global movement of free coding clubs for young people.

 - Awarded 'Teacher of the Month'

## Projects

### <span>Miss Direction</span> <span>Aug 2016</span>

A mapping engine that misguides you:

   - Won award at AIHacks 2016
   - Built by all women team of newbie programmers
   - Using modern technologies such as GoogleMaps, Chrome Extension and Javascript

## Education

### <span>University of Oklahoma, BA Information Technology</span> <span>2011 -- 2014</span>

  - GPA 4.0
  - DB1101 - Basic SQL
  - CS2011 - Java Introduction

## Skills

 - Web development: HTML, CSS, JavaScript
 - Compression: Mpeg, MP4, GIF
